#
# spec file for package atril
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define typelib1 typelib-1_0-AtrilDocument-1_5_0
%define typelib2 typelib-1_0-AtrilView-1_5_0
%define sover   3
%define _version 1.28

Name:           atril
Version:        1.28.1
Release:        1.2
Summary:        MATE Desktop document viewer
License:        GPL-2.0-only AND LGPL-2.0-only
Group:          Productivity/Office/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  python3-libxml2
BuildRequires:  texlive-devel
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(ddjvuapi)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcaja-extension) >= %{_version}
BuildRequires:  pkgconfig(libgxps)
BuildRequires:  pkgconfig(libpst)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(poppler-glib) >= 0.22.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-backends = %{version}
Requires:       mate-desktop-gsettings-schemas >= %{_version}
Recommends:     %{name}-lang
# mate-document-viewer was last used in openSUSE 13.1.
Provides:       mate-document-viewer = %{version}
Obsoletes:      mate-document-viewer < %{version}
Obsoletes:      mate-document-viewer-lang < %{version}
%glib2_gsettings_schema_requires

%description
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

%lang_package

%package -n libatrildocument%{sover}
Summary:        System library of the MATE Document Viewer
Group:          System/Libraries
Obsoletes:      mate-document-viewer-libs-3 < %{version}

%description -n libatrildocument%{sover}
Atril is a document viewer capable of displaying multiple and
singlepage document formats like PDF and PostScript.

%package -n libatrilview%{sover}
Summary:        System library of the MATE Document Viewer
Group:          System/Libraries
Obsoletes:      mate-document-viewer-libs-3 < %{version}

%description -n libatrilview%{sover}
Atril is a document viewer capable of displaying multiple and
singlepage document formats like PDF and PostScript.

%package -n %{typelib1}
Summary:        Introspection bindings for MATE Desktop's AtrilDocument
Group:          System/Libraries

%description -n %{typelib1}
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

%package -n %{typelib2}
Summary:        Introspection bindings for MATE Desktop's AtrilView
Group:          System/Libraries

%description -n %{typelib2}
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

%package backends
Summary:        Atril shared libraries (View and Document)
Requires:       mathjax
# mate-document-viewer-libs-3 was last used in openSUSE 13.1.
Provides:       mate-document-viewer-libs-3 = %{version}
Obsoletes:      mate-document-viewer-libs-3 < %{version}

%description backends
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

%package -n caja-extension-%{name}
Summary:        Atril extension for Caja file manager
Requires:       %{name} = %{version}
Requires:       caja >= %{_version}
Supplements:    (caja and %{name})
# atril-caja was last used in openSUSE Leap 42.1.
Provides:       %{name}-caja = %{version}
Obsoletes:      %{name}-caja < %{version}
# mate-document-viewer-caja was last used in openSUSE 13.1.
Provides:       mate-document-viewer-caja = %{version}
Obsoletes:      mate-document-viewer-caja < %{version}

%description -n caja-extension-%{name}
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

This package contains the Atril extension for the Caja file manager.
It adds an additional tab called "Document" to the file properties
dialog.

%package devel
Summary:        MATE Desktop document viewer development files
Requires:       %{name}-backends = %{version}
Requires:       %{typelib1} = %{version}
Requires:       %{typelib2} = %{version}
# mate-document-viewer-devel was last used in openSUSE 13.1.
Provides:       mate-document-viewer-devel = %{version}
Obsoletes:      mate-document-viewer-devel < %{version}

%description devel
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

%package thumbnailer
Summary:        Atril thumbnailer extension for Caja
Requires:       %{name} = %{version}
Requires:       caja >= %{_version}

%description thumbnailer
Atril is a document viewer capable of displaying multiple and single
page document formats like PDF and Postscript.

This package contains the Atril extension for the Caja file manager.

%package doc
Summary:        Documentation how to Use Atril
Group:          Documentation/HTML
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
This package contains the documentation for atril

%prep
%autosetup -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static                    \
  --libexecdir=%{_libexecdir}/%{name} \
  --enable-introspection
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}/

%post -n libatrilview%{sover} -p /sbin/ldconfig

%postun -n libatrilview%{sover} -p /sbin/ldconfig

%post -n libatrildocument%{sover} -p /sbin/ldconfig

%postun -n libatrildocument%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-previewer
%{_bindir}/%{name}-thumbnailer
%{_datadir}/%{name}/
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/%{sover}/
%dir %{_libexecdir}/%{name}/
%{_libexecdir}/%{name}/%{name}*
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/*/*
%{_mandir}/man?/*.?%{?ext_man}

%files -n libatrilview%{sover}
%license COPYING
%doc AUTHORS README.md
%{_libdir}/libatrilview.so.%{sover}*

%files -n libatrildocument%{sover}
%license COPYING
%doc AUTHORS README.md
%{_libdir}/libatrildocument.so.%{sover}*

%files devel
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/gtk-doc/html/

%files -n caja-extension-%{name}
%{_datadir}/caja/extensions/libatril-properties-page.caja-extension
%{_libdir}/caja/

%files -n %{typelib1}
%{_libdir}/girepository-1.0/AtrilDocument-1.5.0.typelib

%files -n %{typelib2}
%{_libdir}/girepository-1.0/AtrilView-1.5.0.typelib

%files backends
%license COPYING
%doc AUTHORS README.md
%{_libdir}/%{name}/%{sover}/backends/

%files thumbnailer
%dir %{_datadir}/thumbnailers/
%{_datadir}/thumbnailers/atril.thumbnailer

%files doc
%doc %{_datadir}/help/*/%{name}/

%files lang -f %{name}.lang
%exclude %{_datadir}/help/*

%changelog
* Sun Jan 19 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.28.1:
  * Update CBR library to libarchive in README.md
  * ci: fix travis build failures caused by recent travis changes
  * Cleanup icons Makefile
  * icons: Include higher resolution icons
  * Updated translations.
- Drop pkgconfig(libpst) BuildRequires: No longer required nor used
* Mon Mar 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Update translation
  * Fix bugs
- Drop atril-comics-Use-libarchive-to-unpack-documents.patch and
  atril-Use-a-blank-line-at-most.patch
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Jan  1 2024 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Fix CVE-2023-51698: comics: Use libarchive to unpack documents.
  * Add patch: atril-Use-a-blank-line-at-most.patch (required to let
    the actual CVE fix patch apply). Cherry-picked from upstream's
    1.26 branch.
  * Add patch: atril-comics-Use-libarchive-to-unpack-documents.patch.
    Fix for CVE-2023-51698. Cherry-picked from upstream's 1.26 branch.
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * epub: Add fallback for malformed epub files in check_mime_type.
  * epub: Fix index loading for certain documents.
  * Accessibility: Add button description.
  * Preserve compatibility with older GLib versions.
  * Update translations.
- Drop atril-glib-2.54.patch, atril-synctex-1.18.patch.
* Sun Aug 22 2021 Jan Engelhardt <jengelh@inai.de>
- Make documentation noarch. Remove --with-pic because it has no
  effect in conjunction with --disable-static. Update RPM groups.
* Thu Aug 19 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * update translations
  * ev-window.c: only create a EvWebView if needed
  * ev-sidebar-links: Optimize reverse link lookup for a page
  * introspection: Fix bogus --library arguments.
  * libdocument: remove _ev_g_mkdtemp function
  * epub: declaration of ‘uL’ shadows a previous local [-Wshadow]
  * ev-window: missing initializer for a field of ‘GtkActionEntry’
  * epub: fix typo
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.1
  * update translations
  * epub backend: Escape link text to display & in index content
  * Fix segfault on empty navMap
  * thumbnailer: fix typo in the option description
  * Use int64_t for g_date_time_to_unix even word size is 32-bit wide
- Split doc package
* Mon Mar 30 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Add atril-synctex-1.18.patch: Restore SyncTeX 1.18 support.
- Add atril-glib-2.54.patch: Restore GLib 2.54 support.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.0):
  * ev-view: Remove unused variables and assignment
  * Avoid g_type_class_add_private.
  * tiff: Handle failure from TIFFReadRGBAImageOriented.
  * view-presentation: Use monitor instead of screen.
  * shell: Use monitor instead of screen to determine window size.
  * shell: Fix get_monitor_dpi when widget’s window is not
    realized.
  * DPI: Compute monitor resolution or get screen resolution.
  * Prevent segfaults when no document loaded.
  * Require GLib 2.54.0.
  * Fix build warning on marshalling.
  * Suppress GtkAction warnings.
  * document: Replace deprecated gdk_color_equal.
  * Fix buffer overflow in backend/tiff-document.c.
  * Fix atril.desktop file.
  * Fix memory leak ev_sidebar_thumbnails_document_changed_cb().
  * pdf: Fix memory leak when adding new text annotations.
  * libview: Fix a memory leak.
  * Revert "First page should not reloaded"
  * Avoid redundant redeclarations.
  * libview: Reset "pressed_button" when starting Drag and Drop.
  * Show SyncTeX version in the About dialogue.
  * Add a hint for translators.
  * Migrate from intltool to gettext.
  * Add accelerator 'o' for toggling Odd Pages Left.
  * Add accelerator 't' for toggling visibility of the toolbar.
  * Remove synctex internally, work with external library instead.
  * build: Require webkit2gtk-4.0 >= 2.6.0.
  * End the va_list before returning from _synctex_merge_strings.
  * build: Use synctex system library if available.
  * Remove synctex warning.
  * Bump synctex to 1.21.
  * thumbnailer: Fix a memory leak.
  * Fix year 2038 issue with signed 32-bit integers.
  * Update translations.
- Drop support for old openSUSE versions.
* Tue Sep 24 2019 Michel Normand <normand@linux.vnet.ibm.com>
-  Replace BuildRequires: libxml2-python by python3-libxml2
  as libxml2 updated.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * update translations
  * Remove trailing whitespaces
  * test: get focus on frame
  * let test7.py can works
  * force get focus on atril when testing
  * migrate to python3 for test cases
  * Bump Cairo version to 1.14.0
  * Change url project's website
  * help: update copyright
  * Add documenters to translation resource
  * Use program-name and title in gtk_show_about_dialog call
  * Update copyright in about dialog
  * Use g_strjoin to build license text in about dialog
- remove patches:
  * atril-gtk-3.20.patch: we don't need to support gtk-3.20 anymore
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Add documenters to translation resource.
  * Use program-name and title in gtk_show_about_dialog call.
  * help: Update copyright.
  * Update copyright in the About dialogue.
  * Use g_strjoin to build licence text in the About dialogue.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Disable deprecation warnings for distcheck.
  * shell: Don't dist generated files.
  * presentation: Avoid deprecated
    "gtk_style_context_set_background".
  * ev-sidebar-bookmarks: Use NULL instead of an uninitialised
    variable.
  * Avoid deprecated gtk_menu_popup.
  * libview: Replace deprecated gdk_flush.
  * thumbnailer: Remove unused code.
  * Add update-authors.pl script which helps to update atril.about.
  * Read authors (updated) from atril.about gresource.
  * [ephy-zoom-control] Avoid deprecated g_type_class_add_private.
  * [ephy-zoom-action] Avoid deprecated g_type_class_add_private.
  * Add pixbuf, tiff and xps TypeDescription to POTFILES.in.
  * eggsmclient: Avoid deprecated 'g_type_class_add_private'.
  * Move appdata to the metainfo/ directory.
  * message-area: Set a11y object name from actual icon name.
  * shell: Remove duplicate condition check.
  * tiff: Fix possible NULL pointer dereference.
  * pdf: Add missing break statement.
  * libdocument: Drop useless freeing of a NULL pointer.
  * comics: Fix incorrect mimetype saying to open and thumbnail all
    rarfiles.
  * Update translations.
- Rebase atril-gtk-3.20.patch.
* Thu Dec 13 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * Use make functions for HELP_LINGUAS.
  * comics: Support application/vnd.rar MIME type.
  * shell: Save document to the same path it was opened from.
  * Reduce the chattiness of the atril daemon.
  * EvView: Fix cursor movement when logical and visual line order
    differs.
  * Update atril_start_window.png.
  * moveable (older spelling) -> movable.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.2 (changes since 1.20.0):
  * Disable view presentation if there is no document.
  * Allow changing the page of a presentation.
  * libview: Fix goto window in presentation mode.
  * libview: Avoid deprecated gdk_screen_get_monitor.
  * EvPresentationView: Render correctly on hi-dpi displays.
  * libview: Fix g_return condition in
    set_device_scale_on_surface().
  * EvView: Render correctly on hi-dpi displays.
  * libview: Use css to draw the background of presentations.
  * Move custom css to a file compiled as a gresource.
  * shell: Use GResource for data files.
  * toolbar-editor: Add methods to load from GResource.
  * previewer: Use GResource for data files.
  * build: Add configure check for glib-compile-resources.
  * Update resource for translations.
  * libview: Check number of pages when processing button events.
  * libview: Add check for pageless documents to
    ev_view_accessible_focus_changed.
  * libview: Check number of pages on ev_view_document_changed_cb.
  * Use GtkOverlay to show the loading message.
  * shell: Remove unused marshalers.
  * thumbnailer: Send error messages to stderr.
  * shell: Use GtkApplication to inhibit the screensaver.
  * shell: Port to GtkApplication.
  * shell: Use g_printerr instead of g_warning.
  * daemon: Port to GApplication.
  * daemon: Use gdbus-codegen for the org.mate.atril.Daemon
    interface.
  * shell: Use gdbus-codegen for the org.mate.atril.Window
    interface.
  * shell: Use gdbus-codegen for the org.mate.atril.Application
    interface.
  * libview: Save inverted colours in a document
  * Save/restore context when getting colours for a different state.
  * epub: Allow to save epub documents.
  * epub: Fix loading epub thumbnails.
  * shell: Fix menu-accel for inverted colours.
  * shell: Add keypad accels for zoom_reset.
  * Add zoom reset.
  * Avoid deprecated GtkStock.
  * Check legal boundaries of accessible pages.
  * Disable StartPresentation action in fullscreen if document has
    no pages.
  * Disable ViewPresentation action if document has no pages.
  * libdocument: Use gdk_pixbuf_get_from_surface().
  * thumbnailer: Remove unused code.
  * view: Fix page background rendering while loading.
  * libdocument: Deprecate misc_get_page_border_size().
  * view: Use a rendered frame instead of custom border.
  * a11y: Return correct start and end offsets.
  * a11y: Fix crash with Orca screen reader.
  * libview: drop deprecated unneeded code.
  * ev-loading-message: Remove unused variables.
  * libview: fix text selection with mouse in annotation window.
  * libview: fix build without epub.
  * Update translations.
- Rebase atril-gtk-3.20.patch.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * build: Remove a pre-GTK+3 option.
  * epub: Make minizip support more BSD variants.
  * previewer: Add a style class atril-previewer-window.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * shell: Show caret navigation in the menu.
  * ev-link-accessible: Improve efficiency of methods to get start
    and end indices.
  * Expose form fields, images and links as AtkObject children of
    the page.
  * ev-view-accessible: Add a method to determine if a given doc
    rect is showing.
  * ev-page-cache: Add a method to check if a given page has been
    cached.
  * libview: Update the caret cursor when jumping to a find result.
  * libview: Update ATK_STATE_SHOWING when the visible page range
    changes.
  * libview: Implement AtkComponent for pages.
  * libview: Fix shift+click text selection.
  * a11y: Ensure text cached when one request an EvPageAccessible.
  * a11y: Managing atk states on EvPageAccessible.
  * a11y: Add, if applies, ATK_RELATION_FLOWS_TO/FROM on
    EvPageAccessible.
  * a11y: Move the AtkHyperText implementation from
    EvViewAccessible to EvPageAccessible.
  * a11y: Move the AtkText implementation from EvViewAccessible to
    EvPageAccessible.
  * a11y: Expose EvPageAccessible as children of EvViewAccessible.
  * a11y: New EvPageAccessible.
  * libview: Fix some broken aspects of the EvViewAccessible text
    support.
  * libview: Take caret navigation into account when getting
    AtkHyperlink indices.
  * a11y: Clean implementation of atk_text_get_caret_offset().
  * a11y: Fix implementation of atk_text_set_caret_offset().
  * view: set_caret_cursor_position() should emit "cursor-moved" if
    applies.
  * Remove support for deprecated
    atk_text_get_text_{before,after}_offset().
  * a11y: Implement AtkDocument on EvViewAccessible.
  * a11y: With caret navigation enabled, accessibility current page
    is cursor page.
  * ev-view-accessible: Call document_changed_cb when setting the
    model.
  * Some text fixes for caret message area.
  * ev-view-accessible: Fix a crash in ev_view_accessible_get_link.
  * ev-view-accessible: Clear the cached data when the current page.
  * shell: remove view_actions_focus_out_cb.
  * shell: Remove ev_window_set_view_accels_sensitivity.
  * shell: forward accels to the focused widget.
  * Use a global array for view accel action.
  * fix crash when selecting text in djvu documents.
  * shell: fix stock item for message area.
  * docs: libview: Re-add type builtins section.
  * Fix crashes of epub documents with caret-navigation.
  * Store the caret cursor position in document metadata.
  * libview: Add ev_view_set_caret_cursor_position.
  * libview: Update the current page also when pending scroll is to
    find a location.
  * libview: Do not schedule a redraw when enabling/disabling caret
    navigation.
  * libview: Stop caret cursor blinking when cursor is not in a
    visible page.
  * shell: Enable/disable the caret navigation with F7.
  * libview: Add ev_view_supports_caret_navigation().
  * ev-link-accesible: Return the index/offset after the last
    character in the link.
  * help: Remove references to removed selection mode.
  * libview: Fix selections starting/ending in page margins.
  * libview: Reduce the pages to scan for selections.
  * libview: Remove unused rectangle selection mode.
  * libview: Rework ev_view_accessible_get_selection.
  * libview: do not redraw the whole view when caret cursor moves.
  * libview: Update the cursor area after positioning the cursor
    when moving between lines.
  * ev-view-accessible: Fix ev_view_accesssible_get_n_selections.
  * ev-view-accessibl: Fix get_caret_offset when the caret
    navigation is enabled.
  * libview: Use error bell and return early when moving between
    lines fails.
  * libview: do not schedule a resize in ensure_rectangle_is_visible.
  * libview: Stop the cursor blink when there are selections active.
  * libview: Deprecate ev_view_scroll in favour of
    g_signal_emit_by_name.
  * ev-window: Use g_signal_emit_by name instead of ev_view_scroll.
  * previewer: Remove scroll accelerators.
  * ev-window: Remove scroll accelerators.
  * libview: Add more scroll key bindings to EvView.
  * libview: Fix second parameter type of scroll signal for h, j, k
    and l bindings.
  * libview: Use merge_selection_region passing NULL to clear the
    selections.
  * ev-pixbuf-cache: Clear the selection region also when clearing
    the job selection.
  * ev-pixbuf-cache: Fix the condition for when a new selection is
    needed.
  * ev-view-accessible: Rewrite get_run_attributes to return the
    text attributes from the document.
  * pdf: Implement ev_document_text_get_text_attrs().
  * libview: Get text attributes from backend and save them in page
    cache.
  * libdocument: Add ev_document_text_get_text_attrs().
  * libview: Emit the AtkText text-caret-moved and
    text-selection-changed signals.
  * libview: clear the selection when cursor is moved.
  * libview: Do not show the caret cursor when there are active
    selections.
  * libview: Return NULL instead of empty regions from the pixbuf
    cache.
  * libview: Don’t draw the caret cursor when the view is not
    focused.
  * libview: Fix moving caret cursor between lines in multicolumn
    documents.
  * libview: Pre-cache some prev/next pages to the current page
    range.
  * ev-pixbuf-cache: Schedule prev or next jobs first depending on
    the scroll direction.
  * ev-pixbuf-cache: Schedule jobs to render previous pages in
    inverse order.
  * libview: Add the 'cursor-moved' signal to notify when the caret
    cursor has been moved.
  * libview: Avoid unnecessary region copies when selecting text.
  * libview: Use a larger damage area to redraw selections.
  * libview: Don’t queue a redraw when damaged region hasn’t
    changed.
  * libview: Invalidate union of old and new selection.
  * libview: Move the caret cursor when clicking outside a
    selection.
  * libview: Remove unused in_selection member from SelectionInfo
    struct.
  * libview: Keep the offset inside a line when moving the caret
    between lines.
  * libview: Position the caret cursor at beginning/end of the line.
  * libview: Do not schedule a redraw when selecting all text.
  * libview: Use prepend + reverse instead of append to create
    selections list.
  * libview: Use GSlice to allocate EvViewSelection.
  * libview: Text selection using the caret cursor.
  * libview: Update the caret cursor after selecting text with the
    mouse.
  * libview: Take page border into account when computing
    selections.
  * libview: Fix a crash when selecting more than one page.
  * libview: Make sure the cursor blinks after moving it by a click.
  * libview: Merge get_caret_cursor_rect_from_offset and
    get_caret_cursor_area.
  * libview: Notify about caret navigation errors using the error
    bell.
  * libview: Do not redraw after a click if cursor position hasn’t
    changed.
  * libview: Use GtkBindings for caret navigation.
  * libview: Rename EvView::binding-activated signal as
    EvView::scroll.
  * libview: Position the caret cursor by clicking.
  * libview: Use EvPixbufCache to find selection region.
  * libview: Split ev_pixbuf_cache_get_selection_surface into two
    functions.
  * libview: Draw selection highlight from region.
  * libview: Fix the damage area used to redraw the caret cursor.
  * libview: Actually update the page when moving the care from a
    different page.
  * libview: Avoid to update the current page and scroll to the
    cursor position, if the caret cursor was not updated.
  * libview: Make caret cursor blink.
  * libview: Use logical attributes instead text layout to move the
    caret cursor.
  * libview: Add a way to get the text logical attributes from the
    page cache.
  * libview: Initial implementation of caret navigation.
  * libview: Refactor code for drawing page and selection surfaces.
  * shell: disable ViewDualOddLeft in menus for epubs.
  * libview: Only access the relevant page cache for the height
    request.
  * Activate shortcut keys for dual and continuous layout.
  * ev-view: Forward key events to the focused form field.
  * Add shortcut keys for fit-page and fit-width options.
  * shell: Do not open single page pdfs in dual mode by default.
  * libview: Don’t update current_page to negative number.
  * libview: Make page layout a mode.
  * libview: Add new zoom mode that optimises for readability.
  * Rename Fit Page Width as Fit Width.
  * Rename Best Fit mode as Fit Page.
  * Move dual page with odd pages left to the view menu.
  * libview: drop deprecated usage of gtk_container_set_resize_mode.
  * shell: Check if doc implements Annotations interface before
    cast.
  * Refreshing annotations’ sidebar upon deletion.
  * libdocument: Make ev_mapping_list_remove void.
  * page-cache: Add flags parameter to ev_page_cache_mark_dirty().
  * pdf: Reset the annotation mapping when there are no more
    annotations.
  * Add an option to remove annotations to the view popup menu.
  * libview: add ev_view_remove_annotation.
  * pdf: Implement remove_annotation virtual func.
  * libdocument: add ev_mapping_list_remove.
  * libdocument: Add remove_annotation to DocumentAnnotations.
  * pdf: Make annotation names unique.
  * pdf: Add support for adding other types of annotations.
  * libview: Rename ev_view_set_focused_element and make it public
    internally.
  * Change the opacity of the annotation window.
  * Change color of annotation window.
  * libview: Grab focus for form fields and links on mouse press.
  * libdocument: Added ev_mapping_list_get.
  * pdf: Add activation link for Fields that have it.
  * libview: Handle activation link of a Form Field if present.
  * libdocument: Add activation_link to EvFormField struct.
  * ev-properties-licence: don’t use deprecated GtkAlignment.
  * libview: : avoid deprecated gtk_adjustment_changed.
  * ev-job-find: mark two methods as skip.
  * ev-jobs: have ev_job_failed_from_error shadow ev_job_failed.
  * libview: add missing transfer and element-type annotations.
  * ev-mapping-list: make a boxed type.
  * libdocument: add missing transfer and element-type annotations.
  * gtk 3.22: Avoid deprecated gdk_screen_get_monitor_ functions.
  * Avoid gdk_screen_get_primary_monitor,
    gdk_screen_get_monitor_scale_factor.
  * ev-document-misc.c: Avoid deprecated
    gdk_screen_get_width/height_mm.
  * dvi: Mitigate command injection attacks by quoting filename.
  * mdvi-lib: Fix compilation warning (const-correctness).
  * libmisc: set width chars for page label.
  * libview: Scroll small pages in non-continuous mode.
  * libview: Enable GDK_SMOOTH_SCROLL events for view.
  * libview: Ctrl+mouse wheel zoom should be pointer-centred, not
    window-centred.
  * ev-view: Add pan gesture to switch page.
  * ev-view: Explicitly require a GtkScrolledWindow as the parent
    widget.
  * ev-view: Add pinch/zoom gesture to handle document zooming.
  * sidebar-thumbnails: Fix unwanted move to start after fullscreen.
  * sidebar-thumbnails: Preload one extra visible range while
    scrolling.
  * sidebar-thumbnails: Keep thumbnails already rendered.
  * sidebar-thumbnails: Fix clunky scrolling.
  * annotations-sidebar: Clean up the styling.
  * ev-annotation-window: Fix setting the colour of the window
    border.
  * libview: fix annotation window focus change after creation.
  * libview: Fix focus on ev_annotation_window.
  * libview: Don’t change the font color of the annotation window.
  * shell: Use GdkRGBA for annotations.
  * libdocument: Add EvAnnotation API using GdkRGBA.
  * libdocument: Use the new deprecation macros.
  * Add deprecation macros.
  * fix runtime warnings caused by previous HDPI commit.
  * Take monitor scale factor into account when calculating zoom.
  * Add hi-dpi support for main view..
  * shell: Ditch gimpcellrenderertoggle.
  * sidebar-layers: Make it actually usable and fix a runtime
    warning.
  * libview: setting annotation window icons sizes.
  * libview: save changes to a dropdown in an embedded form.
  * libdocument: Adjust rendering of shadow for active and inactive
    pages.
  * avoid deprecated gdk_screen_make_display_name.
  * ev-window: remove deprecated GtkToolbar-shadow-type.
  * annotation-properties-dialog: don’t use a headerbar.
  * Avoid deprecated gdk_display_get_screen and
    gdk_display_get_n_screens.
  * ev-window: don’t use deprecated gtk_show_uri.
  * avoid deprecated gdk_screen_get_number.
  * build: properly clean the generated .caja-extension file.
  * build: require cairo >= 1.10.0 and drop some old code.
  * shell: remove unused code from utils.
  * ev-view: avoid deprecated gtk_drag_begin.
  * egg-editable-toolbar: avoid deprecated gtk_drag_begin.
  * message-area: replace some GtkStock deprecations.
  * ev-sidebar: avoid deprecated GTK_STOCK_CLOSE icon.
  * password-view: replace some GtkStock deprecations.
  * password-view: don’t use deprecated GtkAlignment.
  * toolbar-editor: don’t use deprecated GtkAlignment.
  * Update translations.
- Add atril-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Sun Aug 20 2017 sor.alexei@meowr.ru
- Update to version 1.18.3 (changes since 1.18.1):
  * libmisc: Set character width for page label.
  * EvPixbufCache: Handle backends that don't render a selection.
  * Update translations.
* Sun Aug 20 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Take monitor scale factor into account when calculating zoom.
  * Add hi-dpi support for main view.
  * sidebar-thumbnails: Fix unwanted move to start after
    fullscreen.
  * sidebar-thumbnails: Preload one extra visible range while
    scrolling.
  * sidebar-thumbnails: Keep thumbnails already rendered.
  * sidebar-thumbnails: Fix clunky scrolling.
  * sidebar-layers: Make it actually usable and fix a runtime
    warning.
  * libview: Save changes to a dropdown in an embedded form.
  * ev-window: Remove a deprecated GtkToolbar-shadow-type.
  * annotation-properties-dialog: Don't use a headerbar.
  * comics: Make the files containing "--checkpoint-action="
    unsupported.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require caja >= 1.17.1.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * [comics] Add support for unarchiver (unar and lsar).
  * [libview] Increase the page cache size to reduce the number of
    page reloads.
  * Remove the metadata migration code.
  * Force the X11 backend.
  * Fix lots of GTK+ deprecations.
  * Fix some a11y issues.
  * Some more fixes and cleanups.
  * Update translations.
- Switch to Gtk3.
* Sun Mar  5 2017 sor.alexei@meowr.ru
- Switch to Gtk2 (boo#1028022, gh#mate-desktop/caja#657).
* Tue Nov  1 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Require poppler 0.22.0 (for case-sensitive search in PDFs).
  * [comics] Fix MIME type comparisons.
  * [comics] Support an application/vnd.comicbook+zip MIME type.
  * [djvu] Support an image/vnd.djvu+multipage MIME type.
  * [pdf] Fix case-sensitive search.
  * thumbnailer: Skip epub files (thumbnail generation never
    worked there and caused segfaults).
  * Some code cleanups.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Build: Require poppler 0.18.0.
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Drop dependency on libmate-desktop and --without-matedesktop
    build option.
  * Update toolbar-editor from libegg.
  * Update synctex to 1.18.
  * Split dual mode option into dual mode with odd and even pages
    on the left.
  * Add Ctrl+Up/Down keybindings for previous/next search results.
  * Add caja-sendto support for sending current document by email,
    to removable device, etc.
  * Improve named destinations support with --named-dest command line
    argument and dbus support.
  * [dvi] Use t1 font mapping files.
  * GTK+3: Add style class for view.
  * GTK+3: Fix a possible crash when building with introspection
    enabled.
  * GTK+3: Fix lots of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
- Switch to Gtk3.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Add setting to set page cache size.
  * Add setting to disable auto-reload.
  * Fix some issues with rotated documents.
  * Some more fixes and cleanups.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Tue May 24 2016 sor.alexei@meowr.ru
- Add a missing mathjax dependency to atril-backends.
- Rename atril-caja package to caja-extension-atril.
- Supplement caja-extension-atril if atril and caja are installed.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix several random webview related crashes.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update copyrights, mention MATE team in Caja extension.
  * GTK+3: Add CSS name EggToolbarEditor for 3.20.
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * totem-screensaver: Use org.gnome.SessionManager to inhibit
    screensaver.
  * totem-screensaver: Don't use old API and add ref to TotemScrsaver.
  * totem-screensaver: Fix assertions on entry to TotemScrsaver
    methods.
  * GTK+3: Add atril-window style class to top level.
  * Fix some build warnings.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Update copyrights, mention MATE team in caja extension.
  * Drop MateConf migration script.
* Fri Dec 18 2015 sor.alexei@meowr.ru
- Update to 1.12.2:
  * [epub] Fix crash when accessibility is enabled.
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * [dvi] Fix crash due to regression.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Make smclient mandatory.
  * [epub] drop embedded MathJax in favour of using distro-packaged
  one.
  * Retrieve strings directly from gschema (requires intltool
  0.50.1).
  * Drop mate-icon-theme dependency.
  * Several code cleanups.
* Mon Aug 31 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Fix several command line options.
  * Fix several findbar issues.
  * Make libmatedesktop optional.
  * [pdf] Fix saving annotations added to different pages.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix crash when pressing Esc with no document opened.
  * Gtk3: Add webkit2gtk-4.0 and prefer it over 3.0.
  * Help fixes.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.2):
  * [webkit] Do not connect signal handlers more than once.
  * [webkit] Gtk2: use signals to get notifications about load
    finish and errors (instead of polling in idle function).
  * [webkit] indicate that job failed when the thumbnail loading
    fails.
  * [webkit] changed lock/unlock logic so that there's no locking in
    a function and unlocking in a callback.
  * [libdocument] Fix saving attachments when the name contains a
    path.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  * Fix some crashes
  * comics backend: add support for bsdtar
* Thu Dec 11 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Add ini file for caja extension
  + Add appdata file
  + Many fixed memory leaks from monsta
  + sidebar-thumbnails: connect to job finished signal before scheduling
    the job
  + zero-init all signals arrays
  + Add support for external links to EvViewPresentation
  + Save zoom factor in default settings when sizing mode is free
  + [pdf] Add support for OCG State actions
  + [pdf] Update to poppler api changes
  + [pdf] Do not resolve named destinations in the backend
  + [pdf] Bump poppler requirements to 0.16.0
  + [pdf] Implement document_links_find_link_page()
  + [djvu] Implement document_links_find_link_page()
  + [libdocument] Use find_link_page() instead of find_link_dest() in
    get_dest_page()
  + GDK_KEY_* keys are Gtk+2 as well.
  + [shell] Add timestamp parameter to SyncView
  + [shell] Use new methods to get page and page label from a link
  + [libview] The updated GtkComboBox api is in Gtk+2.24
  + [dvi] Fix drawing glyphs with transparency
  + [shell] Send the URI of the input file instead of the filename in SyncSource
  + [libdocument] Add xz compression support
  + [pdf] Support .pdf.xz files
  + [shell] Add EvBookmarks to handle internal document bookmarks
  + [backends] Fix several security issues in the dvi-backend
  + Small a11y fixes
  + Remember the current page when document is reloaded in presentation mode
  + presentation: Allow to change rotation in presentation mode
  + Rotate with CTRL+Left/Right in presentation mode too
  + Add .png extension when saving images using DnD
  + Gtk3: Use gtk_paned_new() instead gtk_[h|v]paned_new()
  + Gtk3: Add GtkStyleContect support
  + Gtk3: Don't use gdk_cursor_unref()
  + Gtk3: Use gtk_widget_render_icon_pixbuf()
  + Gtk3: presentation: Make sure background window is black by default
    in presentation mode
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Add epub support (part of GSoC 2014).
  + Use MateAboutDialog from libmate-desktop.
- Fix version requirements
- Fix caja subpackage description
- Fix caja subpackage dependency; make depend on caja instead of
  mate-file-manager
- Add a -thumbnailer subpackage
- Add pkgconfig(webkit-1.0) build requirement; needed to build
  epub format backend
- Add pkgconfig(mate-desktop-2.0) build requirement; needed to build
  with about-dialog support
* Mon Sep 29 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Fix crash when clicking empty canvas while loading.
  + Fix FTBFS of atril when build with the clang compiler
  + Add keywords key to .desktop files, close #78
* Fri Sep  5 2014 p.drouand@gmail.com
- Fix mate-desktop-gsettings-schemas version requirement
* Wed Mar 12 2014 p.drouand@gmail.com
- Fix correctly conflicts with mate-document-viewer
* Mon Mar 10 2014 p.drouand@gmail.com
- Fix Provides/Obsoletes tags to avoid conflicts with
  mate-document-viewer
- atril needs atril-backends to work correctly; add a Requires tag
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Initial release (version 1.7.90)
